====================
SNPknock
====================

SNPknock is a simple Python package for creating knockoff copies of variables 
distributed as discrete Markov chains or hidden Markov models. SNPknock also 
includes specific support for knockoff copies of genotype data, through a 
user-friendly interface to the imputation software `fastPhase`.

Released under the GPL-v3 license - see the file LICENSE in the source distribution.
